==> 0.1.1.tar.gz: lib/simple_regexp.dart <==
library simple_regexp;

typedef String ReplaceFunction(Match match) ;

class SimpleRegexp {
  
  static Map<String,RegExp> _re_cache = {} ;
  static Map<String,RegExp> _re_cache_m = {} ;
  static Map<String,RegExp> _re_cache_c = {} ;
  static Map<String,RegExp> _re_cache_mc = {} ;
  
  static Map<String,RegExp> _getRegexpCache(bool multiLine , bool caseSensitive) {

    if ( multiLine && caseSensitive ) {
      return _re_cache_mc ;
    }
    else if ( multiLine ) {
      return _re_cache_m ;
    }
    else if ( caseSensitive ) {
      return _re_cache_c ;
    }
    else {
      return _re_cache ;
    }
    
    throw new StateError('') ;
  }
  
  static void clearRegexpCache() {
    _re_cache.clear() ;
    _re_cache_m.clear() ;
    _re_cache_c.clear() ;
    _re_cache_mc.clear() ;
  }
  
  static void removeFromRegexpCache(String pattern, {bool multiLine: false, bool caseSensitive: true}) {
    _re_cache.remove(pattern) ;
    _re_cache_m.remove(pattern) ;
    _re_cache_c.remove(pattern) ;
    _re_cache_mc.remove(pattern) ;
  }
  
  static RegExp removeFromAllRegexpCaches(String pattern, {bool multiLine: false, bool caseSensitive: true}) {
        Map<String,RegExp> cache = _getRegexpCache(multiLine, caseSensitive) ;
        cache.remove(pattern) ;
    }
  
  static RegExp buildCachedRegexp(String pattern, {bool multiLine: false, bool caseSensitive: true}) {
    Map<String,RegExp> cache = _getRegexpCache(multiLine, caseSensitive) ;
    
    RegExp regexp = cache[pattern] ;
    
    if (regexp != null) return regexp ;
    
    regexp = new RegExp(pattern, multiLine: multiLine, caseSensitive: caseSensitive) ;
    
    cache[pattern] = regexp ;
    
    return regexp ;
  }
  
  static RegExp _REGEXP_match_group = new RegExp(r'(\$\d)', multiLine: true, caseSensitive: true) ;
  
  static ReplaceFunction buildReplaceFunction(String replaceStr) {
    Iterable<Match> ms = _REGEXP_match_group.allMatches(replaceStr) ;
    
    List parts = [] ;
    
    int cursor = 0 ;
    
    for (Match m in ms) {
      parts.add( replaceStr.substring(cursor, m.start) ) ;
      
      String g = m.group(1) ;
      int n = int.parse( g.substring(1) ) ;
      parts.add(n) ;
      
      cursor = m.end ;
    }
    
    parts.add( replaceStr.substring(cursor) ) ;
    
    ReplaceFunction funct = (Match match) {
      String s = '' ;
      
      for (var p in parts) {
        
        if (p is String) {
          String ps = p ;
          s += ps ;
        }
        else {
          int n = p ;
          
          s += match.group(n) ;
        }
      }
      
      return s ;
    };
    
    return funct ;
  }
  
  static String replace(String str, String pattern, String replace, {bool multiLine: false, bool caseSensitive: true}) {
    RegExp regexp = buildCachedRegexp(pattern, multiLine: multiLine, caseSensitive: caseSensitive) ;
    ReplaceFunction funct = buildReplaceFunction(replace) ;
    
    String s = str.replaceAllMapped(regexp, funct) ;
    return s ;
  }
  
}

==> 0.1.3.tar.gz: lib/simple_regexp.dart <==
library simple_regexp;

typedef String ReplaceFunction(Match match) ;

class SimpleRegExp {
  
  static Map<String,RegExp> _re_cache = {} ;
  static Map<String,RegExp> _re_cache_m = {} ;
  static Map<String,RegExp> _re_cache_c = {} ;
  static Map<String,RegExp> _re_cache_mc = {} ;
  
  static Map<String,RegExp> _getRegExpCache(bool multiLine , bool caseSensitive) {

    if ( multiLine && caseSensitive ) {
      return _re_cache_mc ;
    }
    else if ( multiLine ) {
      return _re_cache_m ;
    }
    else if ( caseSensitive ) {
      return _re_cache_c ;
    }
    else {
      return _re_cache ;
    }
    
    throw new StateError('') ;
  }
  
  static void clearRegExpCache() {
    _re_cache.clear() ;
    _re_cache_m.clear() ;
    _re_cache_c.clear() ;
    _re_cache_mc.clear() ;
  }
  
  static void removeFromAllRegExpCaches(String pattern) {
    _re_cache.remove(pattern) ;
    _re_cache_m.remove(pattern) ;
    _re_cache_c.remove(pattern) ;
    _re_cache_mc.remove(pattern) ;
  }
  
  static RegExp removeFromRegExpCache(String pattern, {bool multiLine: false, bool caseSensitive: true}) {
        Map<String,RegExp> cache = _getRegExpCache(multiLine, caseSensitive) ;
        return cache.remove(pattern) ;
    }
  
  static RegExp buildCachedRegExp(String pattern, {bool multiLine: false, bool caseSensitive: true}) {
    Map<String,RegExp> cache = _getRegExpCache(multiLine, caseSensitive) ;
    
    RegExp regexp = cache[pattern] ;
    
    if (regexp != null) return regexp ;
    
    regexp = new RegExp(pattern, multiLine: multiLine, caseSensitive: caseSensitive) ;
    
    cache[pattern] = regexp ;
    
    return regexp ;
  }
  
  static RegExp _REGEXP_match_group = new RegExp(r'(\$\d)', multiLine: true, caseSensitive: true) ;
  
  static ReplaceFunction buildReplaceFunction(String replaceStr) {
    Iterable<Match> ms = _REGEXP_match_group.allMatches(replaceStr) ;
    
    List parts = [] ;
    
    int cursor = 0 ;
    
    for (Match m in ms) {
      parts.add( replaceStr.substring(cursor, m.start) ) ;
      
      String g = m.group(1) ;
      int n = int.parse( g.substring(1) ) ;
      parts.add(n) ;
      
      cursor = m.end ;
    }
    
    parts.add( replaceStr.substring(cursor) ) ;
    
    ReplaceFunction funct = (Match match) {
      String s = '' ;
      
      for (var p in parts) {
        
        if (p is String) {
          String ps = p ;
          s += ps ;
        }
        else {
          int n = p ;
          
          s += match.group(n) ;
        }
      }
      
      return s ;
    };
    
    return funct ;
  }
  
  static String replace(String str, String pattern, String replace, {bool multiLine: false, bool caseSensitive: true}) {
    RegExp regexp = buildCachedRegExp(pattern, multiLine: multiLine, caseSensitive: caseSensitive) ;
    ReplaceFunction funct = buildReplaceFunction(replace) ;
    
    String s = str.replaceAllMapped(regexp, funct) ;
    return s ;
  }
  
}
